import requests

import tkapi.util

from local_settings import USER, PASSWORD, API_ROOT_URL


class TKItem(object):
    def __init__(self, item_json, *args, **kwargs):
        self.json = item_json

    def __dict__(self):
        return self.json

    def __getitem__(self, key):
        return self.__dict__()[key]

    def __setitem__(self, key, item):
        self.__dict__()[key] = item

    @property
    def id(self):
        return self.get_property_or_empty_string('Id')

    def print_json(self):
        tkapi.util.print_pretty(self.json)

    def get_property_or_empty_string(self, property_key):
        if property_key in self.json and self.json[property_key]:
            return str(self.json[property_key])
        return ''

    def get_date_or_none(self, property_key):
        if property_key in self.json and self.json[property_key]:
            return tkapi.util.odatedatetime_to_datetime(self.json[property_key]).date()
        return None

    def get_datetime_or_none(self, property_key):
        if property_key in self.json and self.json[property_key]:
            return tkapi.util.odatedatetime_to_datetime(self.json[property_key])
        return None


def get_all_items(page, max_items=None):
    items = []
    for item in page['value']:
        items.append(item)
    while 'odata.nextLink' in page:
        page = request_json(page['odata.nextLink'])
        for item in page['value']:
            items.append(item)
            if max_items and len(items) >= max_items:
                return items
    return items


def request_json(url, params=None, verbose=False):
    if not params:
        params = {}
    params['$format'] = 'json',
    r = requests.get(API_ROOT_URL + url, params=params, auth=(USER, PASSWORD))
    if verbose:
        print('url: ' + str(r.url))
    if r.status_code != 200:
        print(r.text)
    assert r.status_code == 200
    return r.json()